@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: descriptive
 version: 0.9.4
-id: descriptive-0.9.4-60d90b160af650ae9ec32cf13be1e1df
-key: descr_CNQrVS6OKMhHV4CYjJdS3B
+id: descriptive-0.9.4-53cac459734c9afe653e8ccbd8f6ea25
+key: descr_68C9eh9laXvEMyvGA25LMk
 license: BSD3
 copyright: 2015 Chris Done
 maintainer: chrisdone@gmail.com
@@ -23,11 +23,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/descriptive-0.9.4
 library-dirs: /usr/lib/ghc-7.10.3/site-local/descriptive-0.9.4
 data-dir: /usr/share/arm-linux-ghc-7.10.3/descriptive-0.9.4
-hs-libraries: HSdescriptive-0.9.4-CNQrVS6OKMhHV4CYjJdS3B
+hs-libraries: HSdescriptive-0.9.4-68C9eh9laXvEMyvGA25LMk
 depends:
-    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
+    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    bifunctors-5.2.1-3dea194c07c9b02982b78a82398333cc
+    bifunctors-5.3-bc094c1e88d075fab4936b454b930127
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
